@@ -1,4 +1,4 @@
 from .averagemeter import *
 from .meter_interface import *
-from .printable import item2str
+from .pprint import item2str
 from .storage_interface import *
